@@ -40,7 +40,7 @@
 #' }
 #' 
 #' \code{\link{l2boost}} keeps track of all gradient-correlation coefficients (\emph{rho}) at each iteration in addition to the maximal
-#' descent direction taken by the method. Visuallizing these coefficients can be informative of the inner workings of gradient boosting 
+#' descent direction taken by the method. Visualizing these coefficients can be informative of the inner workings of gradient boosting 
 #' (see the examples in the \code{\link{plot.l2boost}} method).
 #' 
 #' The \code{\link{l2boost}} function uses an arbitrary L1-regularization parameter (nu), and includes the elementary 
@@ -290,7 +290,8 @@ l2boost.default <- function(x, y,
     lr <- l.crit[r]
     
     # extract the R_j,l correlation: only need new values
-    if (r > 1 && (sum(lr == l.crit[1:(r - 1)]) == 0)) {
+    # Do not perform this action if this lr value has been seen before
+    if ( is.null(corr.x[[lr]]) ) {
       corr.x[[lr]] <- extract.corr(x, lr, enet, n.org)
     }
     
